┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/views/dolphinview.h
diff options
context:
space:
mode:
authorElvis Angelaccio <[email protected]>2017-07-27 16:05:18 +0200
committerElvis Angelaccio <[email protected]>2017-07-27 16:05:18 +0200
commit82b2dbd3ec568a6e6fe01a8e75739b25cae25f15 (patch)
tree56d635f989c3f260b8e0539cb6a98506ce84acfc /src/views/dolphinview.h
parent9a957c3b5cec8cb369acc8388240ce718299bcd9 (diff)
parentc3de867622afc7e0eaf787bf371873387a6b4451 (diff)
Merge branch 'Applications/17.08'
Diffstat (limited to 'src/views/dolphinview.h')
-rw-r--r--src/views/dolphinview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/views/dolphinview.h b/src/views/dolphinview.h
index 6b62b5da6..5c832efd1 100644
--- a/src/views/dolphinview.h
+++ b/src/views/dolphinview.h
@@ -363,9 +363,9 @@ public slots:
void pasteIntoFolder();
/**
* Handles a drop of @p dropEvent onto @p destUrl
*/
- void dropUrls(const QUrl &destUrl, QDropEvent *dropEvent);
+ void dropUrls(const QUrl &destUrl, QDropEvent *dropEvent, QWidget *dropWidget);
void stopLoading();
@@ -363,9 +363,9 @@ public slots:
void pasteIntoFolder();
/**
- * Handles a drop of @p dropEvent onto @p destUrl
+ * Handles a drop of @p dropEvent onto widget @p dropWidget and destination @p destUrl
*/